@@ -593,7 +593,7 @@ int getOptionDesc(std::string& options, size_t StartPos, bool IsShortForm, Optio
 }
 
 bool processOption(int OptDescTableIx, Options& Opts, const std::string& Value, bool IsPrefixOption,
-                   bool IsOffFlag, bool IsLC) {
+                   bool IsOffFlag) {
   OptionVariables* ovars = Opts.oVariables;
   OptionDescriptor* od = &OptDescTable[OptDescTableIx];
 
@@ -733,9 +733,7 @@ bool processOption(int OptDescTableIx, Options& Opts, const std::string& Value,
 
       Opts.clcOptions.append(" -D__FAST_RELAXED_MATH__=1");
       Opts.clangOptions.push_back("-D__FAST_RELAXED_MATH__=1");
-      if (IsLC) {  // w/a for SWDEV-116690
-        Opts.clangOptions.push_back("-cl-fast-relaxed-math");
-      }
+      Opts.clangOptions.push_back("-cl-fast-relaxed-math");
 
       // fall-through to handle UnsafeMathOpt
     case OID_UnsafeMathOpt:
@@ -861,10 +859,8 @@ bool processOption(int OptDescTableIx, Options& Opts, const std::string& Value,
       break;
 
     case OID_OptUseNative:
-      if (IsLC) {
-        Opts.llvmOptions.append(" -mllvm -amdgpu-use-native=");
-        Opts.llvmOptions.append(sval);
-      }
+      Opts.llvmOptions.append(" -mllvm -amdgpu-use-native=");
+      Opts.llvmOptions.append(sval);
       break;
 
     case OID_WFComma:
@@ -886,9 +882,7 @@ bool processOption(int OptDescTableIx, Options& Opts, const std::string& Value,
             Opts.clangOptions.push_back(sval);
         } else if (((OptionIdentifier)OptDescTableIx) == OID_WBComma) {
           Opts.llvmOptions.append(" ");
-          if (IsLC) {
-            Opts.llvmOptions.append("-mllvm ");
-          }
+          Opts.llvmOptions.append("-mllvm ");
           Opts.llvmOptions.append(sval);
         } else if (((OptionIdentifier)OptDescTableIx) == OID_WHComma) {
           Opts.finalizerOptions.push_back(sval);
@@ -953,7 +947,7 @@ namespace amd {
 
 namespace option {
 
-bool parseAllOptions(std::string& options, Options& Opts, bool linkOptsOnly, bool isLC) {
+bool parseAllOptions(std::string& options, Options& Opts, bool linkOptsOnly) {
   Opts.origOptionStr = options;
   OptionVariables* ovars = Opts.oVariables;
   OptionDescriptor* od = OptDescTable;
@@ -1084,8 +1078,7 @@ bool parseAllOptions(std::string& options, Options& Opts, bool linkOptsOnly, boo
       if (!(OPTION_info(od) & OA_RUNTIME)) continue;
     }
 
-    if (!processOption(option_ndx, Opts, value, isPrefix_option, (isPrefix_mno || isPrefix_fno),
-                       isLC)) {
+    if (!processOption(option_ndx, Opts, value, isPrefix_option, (isPrefix_mno || isPrefix_fno))) {
       // Keep the optionsLog set in processOption().
       std::string tmpStr("Invalid option: ");
       tmpStr += options.substr(bpos, (pos == std::string::npos) ? pos : pos - bpos);
@@ -1240,8 +1233,7 @@ Options::Options()
       dumpFileRoot(),
       currKernelName(NULL),
       encryptCode(0),
-      MemoryHandles(),
-      libraryType_(amd::LibraryUndefined) {
+      MemoryHandles() {
   oVariables = new OptionVariables();
   ::memset(flags, 0, sizeof(flags));
 
